==> open-cluster-management-operator-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/VeleroBackupConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VeleroBackupConfigFluentImpl<A extends VeleroBackupConfigFluent<A>> extends BaseFluent<A> implements VeleroBackupConfigFluent<A>{
  public VeleroBackupConfigFluentImpl() {
  }
  public VeleroBackupConfigFluentImpl(VeleroBackupConfig instance) {
    this.withEnabled(instance.getEnabled()); 
  }
  private Boolean enabled;
  public Boolean getEnabled() {
    return this.enabled;
  }
  public A withEnabled(Boolean enabled) {
    this.enabled=enabled; return (A) this;
  }
  public Boolean hasEnabled() {
    return this.enabled != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VeleroBackupConfigFluentImpl that = (VeleroBackupConfigFluentImpl) o;
    if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enabled,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enabled != null) { sb.append("enabled:"); sb.append(enabled); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnabled() {
    return withEnabled(true);
  }
  
}

==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/VeleroBackupConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VeleroBackupConfigFluentImpl<A extends VeleroBackupConfigFluent<A>> extends BaseFluent<A> implements VeleroBackupConfigFluent<A>{
  public VeleroBackupConfigFluentImpl() {
  }
  public VeleroBackupConfigFluentImpl(VeleroBackupConfig instance) {
    if (instance != null) {
      this.withEnabled(instance.getEnabled());
    }
  }
  private Boolean enabled;
  public Boolean getEnabled() {
    return this.enabled;
  }
  public A withEnabled(Boolean enabled) {
    this.enabled=enabled; return (A) this;
  }
  public Boolean hasEnabled() {
    return this.enabled != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VeleroBackupConfigFluentImpl that = (VeleroBackupConfigFluentImpl) o;
    if (!java.util.Objects.equals(enabled, that.enabled)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enabled,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enabled != null) { sb.append("enabled:"); sb.append(enabled); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnabled() {
    return withEnabled(true);
  }
  
}
